[comment {-*- text -*- ........ - - -- --- ----- -------- -------------}]
[comment {--- doctools --- manpage}]
[comment {- - -- --- ----- -------- ------------- ---------------------}]
[manpage_begin c::slice n 1]
[include ../include/general.inc]
[titledesc {Create and manipulate C-level array slices}]
[require c::slice [opt 1]]
[keywords  slice {array slice}]
[description]
[include ../include/welcome.inc]

[para] This package provides a basic C API for the creation and use of
continous array slices. It does provide neither Tcl commands nor other
items visible at script level.

[para] The package is meant to be used by other C level data structure
packages, as a means to provide access to parts of their internal
data, assuming that they are (conceptually) an array.

[para] To support this the package provides its C API by means of a
stubs table which can be imported.

[section API]
[list_begin definitions]

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call [type CSLICE] [fun cslice_create] ( [type {long int}] [arg cc], \
	[type void**] [arg cv] )]

This function creates and initializes a slice object with the
specified slice of an array of cells. The return value of the function
is the handle of the new slice object.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call void [fun cslice_destroy] ( [type CSLICE] [arg s] )]

This function destroys the specified slice object, releasing all
allocated memory.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call void [fun cslice_get] ( [type CSLICE] [arg s], \
	[type {long int*}] [arg cc], \
	[type void***] [arg cv] )]

This function provides access to the slice of cells contained in the
specified slice object.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call void [fun cslice_revers] ( [type CSLICE] [arg s] )]

This function creates a new slice which is the reverse of the input.
The input slice is destroyed.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call void [fun cslice_concat] ( \
      [type CSLICE] [arg a] \
      [type CSLICE] [arg b] )]

This function creates a new slice which is the concatenation of the
two inputs. The input slices are destroyed.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call [type CSLICE] [fun cslice_from_list] ( \
      [type Tcl_Interp*] [arg interp] \
      [type Tcl_Obj*] [arg l] )]

This function creates a new slice containing the elements of the Tcl
list object [arg l].

[para] If [arg l] was not a list object [const 0] is returned, and an
error message left in the interpreter [arg interp]. Note that
[arg interp] can be [const 0], in that case no error message is left.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call [type Tcl_Obj*] [fun cslice_to_list] ( \
      [type CSLICE] [arg s] )]

This function creates a new Tcl list object containing the elements
of the slice. This makes sense if and only if the elements of the slice
are of type [type Tcl_Obj*]. Any other type and the resulting Tcl object
is broken, causing a crash at some point in the future.

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call [type {long int}] [fun cslice_size] ( \
      [type CSLICE] [arg s] )]

This function returns the size of the slice [arg s].

[comment {- - -- --- ----- -------- ------------- ---------------------}]
[call [type void*] [fun cslice_at] ( \
      [type CSLICE] [arg s] \
      [type {long int}] [arg at] )]

This function returns the element at index [arg at] in slice [arg s].

[list_end]

[include ../include/license.inc]
[include ../include/feedback.inc]
[manpage_end]
